Content

Enum Content 

pub enum Content {
Show 16 variants Login(Login), GetApiLevel(ApiLevel), GetVersion(Version), Error(ApiError), IsLoggedIn(LoggedIn), Status(Status), GetUnread(Unread), GetFeeds(Vec<Feed>), GetHeadlines(Vec<HeadlineWrapper>), Labels(Vec<Label>), GetArticle(Vec<Headline>), GetConfig(Config), GetPref(Preference), FeedTree(FeedTree), GetCategories(Vec<Category>), GetCounters(Vec<Counter>),
}
Represents the various types of responese from the TTRSS API. The user is expected to inspect the enum for the appropriate type.

Variants



Login(Login)



GetApiLevel(ApiLevel)



GetVersion(Version)



Error(ApiError)



IsLoggedIn(LoggedIn)



Status(Status)



GetUnread(Unread)



GetFeeds(Vec<Feed>)



GetHeadlines(Vec<HeadlineWrapper>)



Labels(Vec<Label>)



GetArticle(Vec<Headline>)



GetConfig(Config)



GetPref(Preference)



FeedTree(FeedTree)



GetCategories(Vec<Category>)



GetCounters(Vec<Counter>)